==> EmiStatR_1.2.0.4.tar.gz: EmiStatR/R/Class-input.R <==
input <- setClass("input", 
                  slots = c(spatial      = "numeric", 
                            zero         = "numeric", 
                            # mc = "numeric", 
                            folder       = "character", 
                            folderOutput = "character",
                            cores        = "numeric", 
                            ww           = "list", 
                            inf          = "list", 
                            rw           = "list", 
                            P1           = "data.frame",
                            st           = "list",
                            pe.ts.file   = "character",
                            pe.daily.file= "character", 
                            pe.weekly    = "list",
                            pe.seasonal  = "list",
                            qs.ts.file   = "character",
                            qs.daily.file= "character", 
                            qs.weekly    = "list",
                            qs.seasonal  = "list",
                            export       = "numeric"),
                  prototype = list(spatial = 0,
                                   zero = 1E-5,
                                   # mc = 0,
                                   folder = system.file("shiny", package = "EmiStatR"),
                                   folderOutput = system.file("shiny", package = "EmiStatR"),
                                   cores = 0,
                                   ww = NULL,
                                   inf = NULL,
                                   rw = NULL,
                                   P1 = NULL,
                                   st = NULL,
                                   pe.ts.file    = "",
                                   pe.daily.file = paste(system.file("shiny/EmiStatR_inputCSO/inputCSO", package = "EmiStatR"), "/pe_factor.csv" ,sep=""), 
                                   pe.weekly     = list(mon=1, tue=1, wed=1, thu=1, fri=1, sat=1, sun=1),
                                   pe.seasonal   = list(jan=1, feb=1, mar=1, apr=1, may=1, jun=1, 
                                                        jul=1, aug=1, sep=1, oct=1, nov=1, dec=1),
                                   qs.ts.file    = "",
                                   qs.daily.file = paste(system.file("shiny/EmiStatR_inputCSO/inputCSO", package = "EmiStatR"), "/qs_factor.csv" ,sep=""),
                                   qs.weekly     = list(mon=1, tue=1, wed=1, thu=1, fri=1, sat=1, sun=1),
                                   qs.seasonal   = list(jan=1, feb=1, mar=1, apr=1, may=1, jun=1, 
                                                        jul=1, aug=1, sep=1, oct=1, nov=1, dec=1),
                                   export = 0)
)

==> EmiStatR_1.2.1.2.tar.gz: EmiStatR/R/Class-input.R <==
input <- setClass("input", 
                  slots = c(spatial      = "numeric", 
                            zero         = "numeric", 
                            # mc = "numeric", 
                            folder       = "character", 
                            #folderOutput = "character",
                            cores        = "numeric", 
                            ww           = "list", 
                            inf          = "list", 
                            rw           = "list", 
                            P1           = "data.frame",
                            st           = "list",
                            pe.ts.file   = "character",
                            pe.daily.file= "character", 
                            pe.weekly    = "list",
                            pe.seasonal  = "list",
                            qs.ts.file   = "character",
                            qs.daily.file= "character", 
                            qs.weekly    = "list",
                            qs.seasonal  = "list",
                            export       = "numeric"),
                  prototype = list(spatial = 0,
                                   zero = 1E-5,
                                   # mc = 0,
                                   folder = system.file("shiny", package = "EmiStatR"),
                                   # folderOutput = system.file("shiny", package = "EmiStatR"),
                                   cores = 0,
                                   ww = NULL,
                                   inf = NULL,
                                   rw = NULL,
                                   P1 = NULL,
                                   st = NULL,
                                   pe.ts.file    = "",
                                   pe.daily.file = paste(system.file("shiny/EmiStatR_inputCSO/inputCSO", package = "EmiStatR"), "/pe_factor.csv" ,sep=""), 
                                   pe.weekly     = list(mon=1, tue=1, wed=1, thu=1, fri=1, sat=1, sun=1),
                                   pe.seasonal   = list(jan=1, feb=1, mar=1, apr=1, may=1, jun=1, 
                                                        jul=1, aug=1, sep=1, oct=1, nov=1, dec=1),
                                   qs.ts.file    = "",
                                   qs.daily.file = paste(system.file("shiny/EmiStatR_inputCSO/inputCSO", package = "EmiStatR"), "/qs_factor.csv" ,sep=""),
                                   qs.weekly     = list(mon=1, tue=1, wed=1, thu=1, fri=1, sat=1, sun=1),
                                   qs.seasonal   = list(jan=1, feb=1, mar=1, apr=1, may=1, jun=1, 
                                                        jul=1, aug=1, sep=1, oct=1, nov=1, dec=1),
                                   export = 1)
)
